@@ -90,7 +90,8 @@ class PPlusConnection(object):
         else:
             # input parameter has priority
             if config_file_path is None:
-                config_cwd_path = os.path.abspath('pplus.cfg')
+
+                config_cwd_path = 'pplus.cfg'
                 config_user_path = os.path.expanduser('~/.pplus/pplus.cfg')
                 config_system_path = os.path.normpath('/etc/pplus/pplus.cfg')
 
